package com.sf.service.service;

import java.util.List;
import com.sf.service.domain.GoodsMessages;

/**
 * 商品信息Service接口
 * 
 * @author zoukun
 * @date 2024-04-18
 */
public interface IGoodsMessagesService 
{
    /**
     * 查询商品信息
     * 
     * @param id 商品信息主键
     * @return 商品信息
     */
    public GoodsMessages selectGoodsMessagesById(Long id);

    /**
     * 查询商品信息列表
     * 
     * @param goodsMessages 商品信息
     * @return 商品信息集合
     */
    public List<GoodsMessages> selectGoodsMessagesList(GoodsMessages goodsMessages);

    /**
     * 新增商品信息
     * 
     * @param goodsMessages 商品信息
     * @return 结果
     */
    public int insertGoodsMessages(GoodsMessages goodsMessages);

    /**
     * 修改商品信息
     * 
     * @param goodsMessages 商品信息
     * @return 结果
     */
    public int updateGoodsMessages(GoodsMessages goodsMessages);

    /**
     * 批量删除商品信息
     * 
     * @param ids 需要删除的商品信息主键集合
     * @return 结果
     */
    public int deleteGoodsMessagesByIds(Long[] ids);

    /**
     * 删除商品信息信息
     * 
     * @param id 商品信息主键
     * @return 结果
     */
    public int deleteGoodsMessagesById(Long id);

    GoodsMessages selectGoodsMessagesByCode(String goodsCode);
}
