package com.sf.service.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.sf.service.domain.GoodsMessages;
import com.sf.service.service.IGoodsMessagesService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.sf.common.annotation.Log;
import com.sf.common.core.controller.BaseController;
import com.sf.common.core.domain.AjaxResult;
import com.sf.common.enums.BusinessType;
import com.sf.common.utils.poi.ExcelUtil;
import com.sf.common.core.page.TableDataInfo;

/**
 * 商品信息Controller
 *
 * @author zoukun
 * @date 2024-04-18
 */
@RestController
@RequestMapping("/service/goods")
public class GoodsMessagesController extends BaseController
{
    @Autowired
    private IGoodsMessagesService goodsMessagesService;

    /**
     * 查询商品信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(GoodsMessages goodsMessages)
    {
        startPage();
        List<GoodsMessages> list = goodsMessagesService.selectGoodsMessagesList(goodsMessages);
        return getDataTable(list);
    }

    /**
     * 导出商品信息列表
     */
    @PreAuthorize("@ss.hasPermi('service:goods:export')")
    @Log(title = "商品信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GoodsMessages goodsMessages)
    {
        List<GoodsMessages> list = goodsMessagesService.selectGoodsMessagesList(goodsMessages);
        ExcelUtil<GoodsMessages> util = new ExcelUtil<GoodsMessages>(GoodsMessages.class);
        util.exportExcel(response, list, "商品信息数据");
    }

    /**
     * 获取商品信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('service:goods:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(goodsMessagesService.selectGoodsMessagesById(id));
    }

    /**
     * 新增商品信息
     */
    @PreAuthorize("@ss.hasPermi('service:goods:add')")
    @Log(title = "商品信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GoodsMessages goodsMessages)
    {
        return toAjax(goodsMessagesService.insertGoodsMessages(goodsMessages));
    }

    /**
     * 修改商品信息
     */
    @PreAuthorize("@ss.hasPermi('service:goods:edit')")
    @Log(title = "商品信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GoodsMessages goodsMessages)
    {
        return toAjax(goodsMessagesService.updateGoodsMessages(goodsMessages));
    }

    /**
     * 删除商品信息
     */
    @PreAuthorize("@ss.hasPermi('service:goods:remove')")
    @Log(title = "商品信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(goodsMessagesService.deleteGoodsMessagesByIds(ids));
    }
}
